You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@superset.apache.org by hu...@apache.org on 2018/08/27 21:00:00 UTC

[incubator-superset] 01/01: add column to annotation model

This is an automated email from the ASF dual-hosted git repository.

hugh pushed a commit to branch update-annotation-model
in repository https://gitbox.apache.org/repos/asf/incubator-superset.git

commit 6c25f549384d7c2fc288451222e50493a7b14104
Author: Hugh Miles <hm...@lyft.com>
AuthorDate: Mon Aug 27 13:59:46 2018 -0700

    add column to annotation model
---
 superset/models/annotations.py | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/superset/models/annotations.py b/superset/models/annotations.py
index 82619fd..1543023 100644
--- a/superset/models/annotations.py
+++ b/superset/models/annotations.py
@@ -8,7 +8,7 @@ from __future__ import unicode_literals
 
 from flask_appbuilder import Model
 from sqlalchemy import (
     Column, DateTime, ForeignKey, Index, Integer, String, Text,
 )
 from sqlalchemy.orm import relationship
 
@@ -42,6 +42,7 @@ class Annotation(Model, AuditMixinNullable):
     layer = relationship(
         AnnotationLayer,
         backref='annotation')
+    annotation_metadata = Column(JSON)
 
     __table_args__ = (
         Index('ti_dag_state', layer_id, start_dttm, end_dttm),
@@ -8,7 +8,7 @@ from __future__ import unicode_literals
 from flask_appbuilder import Model
 from sqlalchemy import (
-    Column, DateTime, ForeignKey, Index, Integer, String, Text,
+    Column, DateTime, ForeignKey, Index, Integer, String, Text, JSON
 )
 from sqlalchemy.orm import relationship